==> blancoOmegatUtil-0.0.5-src.zip: src/blanco/xliff2tmx/message/BlancoXliff2TmxMessageResourceBundle.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * \[Xoh`쐬ꂽ\[XohNXB
 */
package blanco.xliff2tmx.message;

import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * \[Xoh`[BlancoXliff2TmxMessage/bZ[W`[BlancoXliff2Tmx]Iɗp郊\[XohNXB]̃\[XohNXB
 *
 * ̃NX̓\[Xoh`玩ꂽ\[XohNXłB<BR>
 */
class BlancoXliff2TmxMessageResourceBundle {
    /**
     * \[XohIuWFNgB
     *
     * IɎۂɓ͂s\[XohL܂B
     */
    private ResourceBundle fResourceBundle;

    /**
     * BlancoXliff2TmxMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoXliff2TmxMessage]AftHg̃P[AĂяõNX[_gpāA\[Xoh擾܂B
     */
    public BlancoXliff2TmxMessageResourceBundle() {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoXliff2TmxMessage");
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoXliff2TmxMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoXliff2TmxMessage]Aw肳ꂽP[AĂяõNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     */
    public BlancoXliff2TmxMessageResourceBundle(final Locale locale) {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoXliff2TmxMessage", locale);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoXliff2TmxMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoXliff2TmxMessage]Aw肳ꂽP[Aw肳ꂽNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     * @param loader NX[_̎w
     */
    public BlancoXliff2TmxMessageResourceBundle(final Locale locale, final ClassLoader loader) {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoXliff2TmxMessage", locale, loader);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * IɕێĂ郊\[XohIuWFNg擾܂B
     *
     * @return IɕێĂ郊\[XohIuWFNgB
     */
    public ResourceBundle getResourceBundle() {
        return fResourceBundle;
    }
}

==> blancoOmegatUtil-0.0.9-src.zip: src/blanco/xliff2tmx/message/BlancoXliff2TmxMessageResourceBundle.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * \[Xoh`쐬ꂽ\[XohNXB
 */
package blanco.xliff2tmx.message;

import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * \[Xoh`[BlancoXliff2TmxMessage/bZ[W`[BlancoXliff2Tmx]Iɗp郊\[XohNXB]̃\[XohNXB
 *
 * ̃NX̓\[Xoh`玩ꂽ\[XohNXłB<BR>
 */
class BlancoXliff2TmxMessageResourceBundle {
    /**
     * \[XohIuWFNgB
     *
     * IɎۂɓ͂s\[XohL܂B
     */
    private ResourceBundle fResourceBundle;

    /**
     * BlancoXliff2TmxMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoXliff2TmxMessage]AftHg̃P[AĂяõNX[_gpāA\[Xoh擾܂B
     */
    public BlancoXliff2TmxMessageResourceBundle() {
        try {
            fResourceBundle = ResourceBundle.getBundle("blanco/xliff2tmx/message/BlancoXliff2TmxMessage");
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoXliff2TmxMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoXliff2TmxMessage]Aw肳ꂽP[AĂяõNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     */
    public BlancoXliff2TmxMessageResourceBundle(final Locale locale) {
        try {
            fResourceBundle = ResourceBundle.getBundle("blanco/xliff2tmx/message/BlancoXliff2TmxMessage", locale);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoXliff2TmxMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoXliff2TmxMessage]Aw肳ꂽP[Aw肳ꂽNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     * @param loader NX[_̎w
     */
    public BlancoXliff2TmxMessageResourceBundle(final Locale locale, final ClassLoader loader) {
        try {
            fResourceBundle = ResourceBundle.getBundle("blanco/xliff2tmx/message/BlancoXliff2TmxMessage", locale, loader);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * IɕێĂ郊\[XohIuWFNg擾܂B
     *
     * @return IɕێĂ郊\[XohIuWFNgB
     */
    public ResourceBundle getResourceBundle() {
        return fResourceBundle;
    }
}
